@@ -32,7 +32,7 @@ refresh <- function() {
 	if( !is.nothing) {
 		data.select <- as.numeric( tkcurselection( data.listbox))+1
 		dd <- get( full.list[ data.select])
-		} else dd <- .ev
+		} else dd <- extRemesData
 
 	for( i in 1:ncol(dd$data))
         	tkinsert( resp.listbox, "end",
@@ -62,7 +62,7 @@ redolists<-function() {
 	if( !is.nothing) {
 		data.select <- as.numeric( tkcurselection( data.listbox))+1
 		dd <- get( full.list[ data.select])
-	} else dd <- .ev
+	} else dd <- extRemesData
 
 resp.name <-
 	colnames(dd$data)[as.numeric(tkcurselection(resp.listbox))+1] 
@@ -89,11 +89,15 @@ submit <- function() {
 
 	if( !is.nothing) {
                 data.select <- as.numeric( tkcurselection( data.listbox))+1
-                dd <- get( full.list[ data.select])
-                } else dd <- .ev
+                dd.cmd <- paste("dd <- get( \"", full.list[ data.select], "\")", sep="")
+                } else dd.cmd <- "dd <- extRemesData"
+	eval( parse( text=dd.cmd))
+	write( dd.cmd, file="extRemes.log", append=TRUE)
 
     # names of the covariates used (if any) 
-    cov.names<-character(0) 
+    cov.names.cmd <- "cov.names<-character(0)"
+	eval( parse( text=cov.names.cmd))
+	write( cov.names.cmd, file="extRemes.log", append=TRUE)
 
     resp.select<-as.numeric(tkcurselection(resp.listbox))+1
  
@@ -102,140 +106,210 @@ submit <- function() {
       return()
 
 
-	tkconfigure(base.txt,state="normal")
+	# tkconfigure(base.txt,state="normal")
 	nl1 <- paste("  ", "************", "   ", "   ", sep="\n")
 	nl2 <- paste( "   ", " ", sep="\n")
-	tkinsert( base.txt, "end", nl2)
-	tkinsert( base.txt, "end", nl1)
-	tkinsert( base.txt,"end",paste("GEV fit \n"))
-	tkinsert(base.txt,"end",paste("-----------------------------------\n"))
-	tkinsert(base.txt,"end",paste("Response variable:",
- 	            colnames( dd$data)[ resp.select], "\n"))
-	tkinsert( base.txt, "end", nl2)
+	# tkinsert( base.txt, "end", nl2)
+	cat( nl2)
+	# tkinsert( base.txt, "end", nl1)
+	cat( nl1)
+	# tkinsert( base.txt,"end",paste("GEV fit \n"))
+	cat( paste("GEV fit \n"))
+	# tkinsert(base.txt,"end",paste("-----------------------------------\n"))
+	cat( paste("-----------------------------------\n"))
+	# tkinsert(base.txt,"end",paste("Response variable:",
+ 	 #            colnames( dd$data)[ resp.select], "\n"))
+	cat( paste("Response variable:", colnames( dd$data)[ resp.select], "\n"))
+	# tkinsert( base.txt, "end", nl2)
+	cat( nl2)
 
     # process the covariates and link functions
-	covs <- NULL
+	covs.cmd <- "covs <- NULL"
+	eval( parse( text=covs.cmd))
+	write( covs.cmd, file="extRemes.log", append=TRUE)
 	cur.cov.cols<-0
+	# eval( parse( text=cur.cov.cols.cmd))
+	# write( cur.cov.cols.cmd, file="extRemes.log", append=TRUE)
 
 	# do the mu
-	mu.cov.cols <- NULL
+	mu.cov.cols.cmd <- "mu.cov.cols <- NULL"
+	eval( parse( text=mu.cov.cols.cmd))
+	write( mu.cov.cols.cmd, file="extRemes.log", append=TRUE)
+
 	if( tclvalue( tkcurselection(mu.covlist)) !="") {
 
       # get the right covariates
      # temp.cols <- as.numeric( strsplit(tkcurselection(mu.covlist)," ")[[1]])
 temp.cols <- as.numeric( unlist( strsplit( tclvalue( tkcurselection(mu.covlist)), " ")))
-      cov.selected <- character(0)
+	cov.selected.cmd <- "cov.selected <- character(0)"
+	eval( parse( text=cov.selected.cmd))
+	write( cov.selected.cmd, file="extRemes.log", append=TRUE)
       for (i in temp.cols) {
-        cov.selected <- c( cov.selected, tclvalue( tkget( mu.covlist, i)))  
+        cov.selected.cmd <- paste( "cov.selected <- c( cov.selected, \"", tclvalue( tkget( mu.covlist, i)), "\")", sep="")
+	eval( parse( text=cov.selected.cmd))
+	write( cov.selected.cmd, file="extRemes.log", append=TRUE)
       }
 print(  paste( "cov.selected = ", cov.selected, sep=""))
       # match the covariate names to the cols of 'dd'
  
-      dat.cols<-numeric(0)
+      dat.cols.cmd <- "dat.cols<-numeric(0)"
+	eval( parse( text=dat.cols.cmd))
+	write( dat.cols.cmd, file="extRemes.log", append=TRUE) 
       for (j in 1:length(colnames(dd$data))) {
         for (i in cov.selected) {
           if (i == colnames(dd$data)[j]) {
-            dat.cols<-c(dat.cols,j)
+            dat.cols.cmd <- paste("dat.cols<-c(dat.cols,", j, ")", sep="")
+		eval( parse( text=dat.cols.cmd))
+		write( dat.cols.cmd, file="extRemes.log", append=TRUE)
           } 
         }
       }
  
-      covs <- cbind(covs,as.matrix(dd$data[,dat.cols]))
-      mu.cov.cols<-(cur.cov.cols+1):(length(dat.cols)+cur.cov.cols)
+      # covs <- cbind(covs,as.matrix(dd$data[,dat.cols]))
+	covs.cmd <- "covs <- cbind( covs, as.matrix( dd[[\"data\"]][, dat.cols]))"
+	eval( parse( text=covs.cmd))
+	# covs.cmd <- paste( "covs <- cbind(covs, as.matrix(", full.list[ data.select], "$data[,dat.cols]))", sep="")
+	write( covs.cmd, file="extRemes.log", append=TRUE)
+      mu.cov.cols.cmd <- paste( "mu.cov.cols <- ", cur.cov.cols+1, ":", length(dat.cols)+cur.cov.cols, sep="")
+	eval( parse( text=mu.cov.cols.cmd))
+	write( mu.cov.cols.cmd, file="extRemes.log", append=TRUE)
       cur.cov.cols<-cur.cov.cols+length(dat.cols)
-      cov.names <- c( cov.names, colnames( dd$data)[ dat.cols])
+      # cov.names <- c( cov.names, colnames( dd$data)[ dat.cols])
+	cov.names.cmd <- "cov.names <- c( cov.names, colnames( dd[[\"data\"]])[ dat.cols])"
+	eval( parse( text=cov.names.cmd))
+# cov.names.cmd <- paste( "cov.names <- c( cov.names, colnames( ", full.list[ data.select], "$data[ dat.cols]))", sep="")
+	write( cov.names.cmd, file="extRemes.log", append=TRUE)
     }
 
 
 
     # do the sigma 
    
-    sig.cov.cols <- NULL 
+    sig.cov.cols.cmd <- "sig.cov.cols <- NULL"
+	eval( parse( text=sig.cov.cols.cmd))
+	write( sig.cov.cols.cmd, file="extRemes.log", append=TRUE)
     if (tclvalue( tkcurselection(sig.covlist)) !="") {
 
      # get the right covariates
      # temp.cols<-as.numeric(strsplit(tkcurselection(sig.covlist)," ")[[1]])
 temp.cols <- as.numeric( unlist( strsplit( tclvalue( tkcurselection(sig.covlist)), " ")))
-      cov.selected<-character(0)
+      cov.selected.cmd <- "cov.selected<-character(0)"
+	eval( parse( text=cov.selected.cmd))
+	write( cov.selected.cmd, file="extRemes.log", append=TRUE)
       for (i in temp.cols) {
-        cov.selected <- c( cov.selected, tclvalue( tkget(sig.covlist,i)))
+        cov.selected.cmd <- paste( "cov.selected <- c( cov.selected, \"", tclvalue( tkget(sig.covlist,i)), "\")", sep="")
+	eval( parse( text=cov.selected.cmd))
+	write( cov.selected.cmd, file="extRemes.log", append=TRUE)
       }
  
       # match the covariate names to the cols of 'dd'
  
-      dat.cols<-numeric(0)
+      dat.cols.cmd <- "dat.cols<-numeric(0)"
+	eval( parse( text=dat.cols.cmd))
+	write( dat.cols.cmd, file="extRemes.log", append=TRUE)
       for (j in 1:length(colnames(dd$data))) {
         for (i in cov.selected) {
           if (i == colnames(dd$data)[j]) {
-            dat.cols<-c(dat.cols,j)
+            dat.cols.cmd <- paste( "dat.cols<-c(dat.cols,", j, ")", sep="")
+		eval( parse( text=dat.cols.cmd))
+        write( dat.cols.cmd, file="extRemes.log", append=TRUE)
           }
         }
       }
 
 
-      covs <- cbind(covs,as.matrix(dd$data[,dat.cols]))
-      sig.cov.cols<-(cur.cov.cols+1):(length(dat.cols)+cur.cov.cols)
+      # covs <- cbind(covs,as.matrix(dd$data[,dat.cols]))
+	covs.cmd <- "covs <- cbind( covs, as.matrix( dd[[\"data\"]][, dat.cols]))"
+	eval( parse( text=covs.cmd))
+	# covs.cmd <- paste( "covs <- cbind(covs, as.matrix( ", full.list[ data.select], "$data[, dat.cols]))", sep="")
+	write( covs.cmd, file="extRemes.log", append=TRUE)
+      sig.cov.cols.cmd <- paste( "sig.cov.cols<-", (cur.cov.cols+1), ":", (length(dat.cols)+cur.cov.cols), sep="")
+	eval( parse( text=sig.cov.cols.cmd))
+	write( sig.cov.cols.cmd, file="extRemes.log", append=TRUE)
       cur.cov.cols<-cur.cov.cols+length(dat.cols)
-      cov.names<-c(cov.names,colnames(dd$data)[dat.cols])
+# cov.names<-c(cov.names,colnames(dd$data)[dat.cols])
+# cov.names.cmd <- paste( "cov.names<-c(cov.names, colnames( ", full.list[ data.select], "$data)[dat.cols])", sep="")
+	cov.names.cmd <- "cov.names <- c( cov.names, colnames( dd[[\"data\"]])[dat.cols])"
+	eval( parse( text=cov.names.cmd))
+	write( cov.names.cmd, file="extRemes.log", append=TRUE)
     }
 
 
     # do the gamma
     
-    gam.cov.cols<-NULL
+    gam.cov.cols.cmd <- "gam.cov.cols<-NULL"
+	eval( parse( text=gam.cov.cols.cmd))
+	write( gam.cov.cols.cmd, file="extRemes.log", append=TRUE)
     if (tclvalue( tkcurselection(gam.covlist)) !="") {
 
      # get the right covariates
 #      temp.cols<-as.numeric(strsplit(tkcurselection(gam.covlist)," ")[[1]])
 	temp.cols <- as.numeric( unlist( strsplit( tclvalue( tkcurselection(gam.covlist)), " ")))
-      cov.selected<-character(0)
+      cov.selected.cmd <- "cov.selected<-character(0)"
+	eval( parse( text=cov.selected.cmd))
+	write( cov.selected.cmd, file="extRemes.log", append=TRUE)
       for (i in temp.cols) {
-        cov.selected <- c( cov.selected, tclvalue( tkget( gam.covlist,i)))
+        cov.selected.cmd <- paste( "cov.selected <- c( cov.selected, \"", tclvalue( tkget( gam.covlist,i)), "\")", sep="")
+	eval( parse( text=cov.selected.cmd))
+        write( cov.selected.cmd, file="extRemes.log", append=TRUE)
       }
  
       # match the covariate names to the cols of 'dd'
  
-      dat.cols<-numeric(0)
+      dat.cols.cmd <- "dat.cols<-numeric(0)"
+	eval( parse( text=dat.cols.cmd))
+	write( dat.cols.cmd, file="extRemes.log", append=TRUE)
       for (j in 1:length(colnames(dd$data))) {
         for (i in cov.selected) {
           if (i == colnames(dd$data)[j]) {
-            dat.cols<-c(dat.cols,j)
+            dat.cols.cmd <- paste("dat.cols<-c(dat.cols,", j, ")", sep="")
+		eval( parse( text=dat.cols.cmd))
+        	write( dat.cols.cmd, file="extRemes.log", append=TRUE)
           }
         }
       }
 
-      covs <- cbind(covs,as.matrix(dd$data[,dat.cols]))
-      gam.cov.cols<-(cur.cov.cols+1):(length(dat.cols)+cur.cov.cols)
+# covs <- cbind(covs,as.matrix(dd$data[,dat.cols]))
+# covs.cmd <- paste( "covs <- cbind(covs, as.matrix( ", full.list[ data.select], "$data[, dat.cols]))", sep="")
+	covs.cmd <- "covs <- cbind( covs, as.matrix( dd[[\"data\"]][, dat.cols]))"
+	eval( parse( text=covs.cmd))
+	write( covs.cmd, file="extRemes.log", append=TRUE)
+      gam.cov.cols.cmd <- paste( "gam.cov.cols<-", (cur.cov.cols+1), ":", (length(dat.cols)+cur.cov.cols), sep="")
+	eval( parse( text=gam.cov.cols.cmd))
+	write( gam.cov.cols.cmd, file="extRemes.log", append=TRUE)
       cur.cov.cols<-cur.cov.cols+length(dat.cols)
-      cov.names<-c(cov.names,colnames(dd$data)[dat.cols])
+# cov.names<-c(cov.names,colnames(dd$data)[dat.cols])
+# cov.names.cmd <- paste( " cov.names<-c(cov.names, colnames( ", full.list[ data.select], "$data)[ dat.cols])", sep="")
+	cov.names.cmd <- "cov.names <- c( cov.names, colnames( dd[[\"data\"]])[dat.cols])"
+	eval( parse( text=cov.names.cmd))
+	write( cov.names.cmd, file="extRemes.log", append=TRUE)
     }
 
 
     # process the link functions for each
-    if (tclvalue(mu.link) =="identity") {
-      m.linker<-identity
-    }
-    else {
-      m.linker<-exp
-    }
+    if (tclvalue(mu.link) =="identity") m.linker.cmd <- "m.linker<-identity"
+    else m.linker.cmd <- "m.linker<-exp"
+	eval( parse( text=m.linker.cmd))
+        write( m.linker.cmd, file="extRemes.log", append=TRUE)
+ 
 
-    if (tclvalue(sig.link) =="identity") {
-      sig.linker<-identity
-    }
-    else {
-      sig.linker<-exp
-    }
+    if (tclvalue(sig.link) =="identity") sig.linker.cmd <- "sig.linker<-identity"
+    else sig.linker.cmd <- " sig.linker<-exp"
+	eval( parse( text=sig.linker.cmd))
+	write( sig.linker.cmd, file="extRemes.log", append=TRUE)
 
-    if (tclvalue(gam.link) =="identity") {
-      gam.linker<-identity
-    }
-    else {
-      gam.linker<-exp
-    }
+    if (tclvalue(gam.link) =="identity") gam.linker.cmd <- "gam.linker<-identity"
+    else gam.linker.cmd <- "gam.linker<-exp"
+	eval( parse( text=gam.linker.cmd))
+        write( gam.linker.cmd, file="extRemes.log", append=TRUE)
 
 method.list <- c("Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN")
 method.select <- as.numeric( tkcurselection( method.listbox))+1
-method.value <- method.list[ method.select]
+if( length( method.select) == 0) {
+		cat( paste( "No optimization method selected.  Using \"BFGS\"",
+			"(use \'help( optim)\' for more details)"), sep="\n")
+		method.value <- "BFGS"
+} else method.value <- method.list[ method.select]
 
 	number.of.models <- length( dd$models)
 	names.of.models <- names( dd$models)
@@ -245,52 +319,75 @@ if( number.of.models > 0) for( i in 1:number.of.models) if( class( dd$models[[i]
 	names.of.models <- c( names.of.models, paste( "gev.fit", jj+1, sep=""))
 
 	# fit the GEV
-	dd$models[[number.of.models+1]] <- gev.fit(dd$data[,resp.select],ydat=covs,
-                      mul=mu.cov.cols,mulink=m.linker,sigl=sig.cov.cols,
-                      siglink=sig.linker,shl=gam.cov.cols,shlink=gam.linker,
-			method=method.value)
-	names( dd$models) <- names.of.models
-	class( dd$models[[number.of.models+1]]) <- "gev.fit"
-	if (is.null(dd$models[[number.of.models+1]])) {
-
-      # failure to fit
+# xdata.cmd <- paste( "xdata <- ", full.list[ data.select], "$data[,", resp.select, "]", sep="")
+xdata.cmd <- paste( "xdata <- dd[[\"data\"]][, ", resp.select, "]", sep="")
+eval( parse( text=xdata.cmd))
+write( xdata.cmd, file="extRemes.log", append=TRUE)
+# xdata <- dd$data[, resp.select]
+	cmd <- paste( "dd[[\"models\"]][[\"gev.fit", jj+1, "\"]] <- ",
+			"gev.fit( xdat=xdata, ydat=covs, mul=mu.cov.cols, mulink=m.linker, sigl=sig.cov.cols, ",
+			"siglink=sig.linker, shl=gam.cov.cols, shlink=gam.linker, method=\"", method.value, "\")", sep="")
+	eval( parse( text=cmd))
+	write( cmd, file="extRemes.log", append=TRUE)
+	# dd$models[[number.of.models+1]] <- eval( parse( text=cmd))
+	# cmd <- paste( full.list[ data.select], "$models$gev.fit", jj+1, " <- ", cmd, sep="")
+	# write( cmd, file="extRemes.log", append=TRUE)
+	# names( dd$models) <- names.of.models
+	# class( dd$models[[number.of.models+1]]) <- "gev.fit"
+	# class.cmd <- paste( "class( ", full.list[ data.select], "$models$gev.fit", jj+1, ") <- \"gev.fit\"", sep="")
+	classCMD <- paste( "class( dd[[\"models\"]][[", number.of.models+1, "]]) <- \"gev.fit\"", sep="")
+	eval( parse( text=classCMD))
+	write( classCMD, file="extRemes.log", append=TRUE)
 
+if (is.null(dd$models[[number.of.models+1]])) {
+# failure to fit 
+	# tkconfigure( base.txt, state="normal")
       fail.str<-paste(" ", "Fit failed.", " ", sep="\n")
-      tkinsert(base.txt,"end",fail.str)
+	cat( fail.str)
+      # tkinsert(base.txt,"end",fail.str)
       tkyview.moveto(base.txt,1.0)
+	# tkconfigure( base.txt, state="disabled")
+} else {
 
-    }
-    else {
-
-#	if( is.nothing) assign( ".ev", dd, pos=".GlobalEnv")
+#	if( is.nothing) assign( "extRemesData", dd, pos=".GlobalEnv")
 #	else assign( full.list[ data.select], dd, pos=".GlobalEnv")
 	# end of if else is.nothing stmt
 
       # print the output
-	fit.obj <- dd$models[[number.of.models+1]]
-
+	# fit.obj <- dd$models[[number.of.models+1]]
+	# fit.obj.cmd <- paste( "fit.obj <- ", full.list[ data.select], "$models$gev.fit", jj+1, sep="")
+	fit.obj.cmd <- paste( "fit.obj <- dd[[\"models\"]][[", number.of.models+1, "]]", sep="")
+	eval( parse( text=fit.obj.cmd))
+	# write( fit.obj.cmd, file="extRemes.log", append=TRUE)
       links<-c(tclvalue(mu.link),tclvalue(sig.link),tclvalue(gam.link))
 
 # Print some informative output to the main gui window.
-      tkconfigure(base.txt,state="normal")
-	nl2 <- paste( "   ", "   ", sep="\n")
-	tkinsert( base.txt, "end", nl2)
+      # tkconfigure(base.txt,state="normal")
+ 	nl2 <- paste( "   ", "   ", sep="\n")
+	cat( nl2)
+# 	tkinsert( base.txt, "end", nl2)
 
 	# Print info about convergence of 'optim' function.
-	if( fit.obj$conv == 0)
-		CONV.msg <- paste("Convergence successfull!")
-	else if( fit.obj$conv == 1)
-		CONV.msg <- paste("Iteration limit exceeded.",
-					"Did not convergence.", sep="\n")
-	else if( fit.obj$conv == 51 | fit.obj$conv == 52)
-		CONV.msg <- paste( fit.obj$message)
+	if( fit.obj$conv == 0) CONV.msg <- paste("Convergence successfull!")
+	else if( fit.obj$conv == 1) CONV.msg <- paste("Iteration limit exceeded.", "Did not convergence.", sep="\n")
+	else if( fit.obj$conv == 51 | fit.obj$conv == 52) CONV.msg <- paste( fit.obj$message)
 	else CONV.msg <- paste("Convergence: ", fit.obj$conv, " (See help for optim for more info).", sep="")
 
-	tkinsert( base.txt, "end", CONV.msg)
-	tkinsert( base.txt, "end", nl2)
+# 	tkinsert( base.txt, "end", CONV.msg)
+# 	tkinsert( base.txt, "end", nl2)
+	cat( "\n", CONV.msg)
 	c1 <- round( cbind( fit.obj$mle, fit.obj$se), digits=5)
+	# c1.cmd <- "c1 <- round( cbind( fit.obj[[\"mle\"]], fit.obj[[\"se\"]]), digits=5)"
+	# eval( parse( text=c1.cmd))
+	# write( c1.cmd, file="extRemes.log", append=TRUE)
 	colnames( c1) <- c( "MLE", "Stand. Err.")
-	rnames <- c( paste( "MU:	(", links[1], ")", sep=""))
+	# colnamesCMD <- "colnames( c1) <- c( \"MLE\", \"Stand. Err.\")"
+	# eval( parse( text=colnamesCMD))
+	# write( colnamesCMD, file="extRemes.log", append=TRUE)
+	rnames <- c( paste( "MU: (", links[1], ")", sep=""))
+	# rnames.cmd <- paste( "rnames <- c( paste( \"MU: (\"", links[1], "\")\", sep=\"\"))", sep="")
+	# eval( parse( text=rnames.cmd))
+	# write( rnames.cmd, file="extRemes.log", append=TRUE)
 	if( !is.null( fit.obj$model[[1]]))
 		rnames <- c(rnames, paste( cov.names[ fit.obj$model[[1]]],
 				": (", links[1], ")", sep=""))
@@ -307,42 +404,58 @@ if( number.of.models > 0) for( i in 1:number.of.models) if( class( dd$models[[i]
 	# Try to assign parameter names to the fitted object for summary purposes.
 	dd$models[[number.of.models+1]]$parameter.names <- rnames
 	dd$models[[number.of.models+1]]$summary1 <- c1
- if( is.nothing) assign( ".ev", dd, pos=".GlobalEnv")
-        else assign( full.list[ data.select], dd, pos=".GlobalEnv")
+ if( is.nothing) assignCMD <- "assign( \"extRemesData\", dd, pos=\".GlobalEnv\")"
+        else assignCMD <- paste( "assign( \"", full.list[ data.select], "\", dd, pos=\".GlobalEnv\")", sep="")
+eval( parse( text=assignCMD))
+write( assignCMD, file="extRemes.log", append=TRUE)
 
-	tkinsert( base.txt, "end", paste( "			",
-					colnames( c1)[1], "		",
-					colnames( c1)[2]))
-	tkinsert( base.txt, "end", nl2)
-	for( i in 1:dim( c1)[1]) {
-		tkinsert( base.txt, "end",
-			paste( rownames( c1)[i], "	", c1[i,1],
-					"	", c1[i,2], sep="  "))
-		tkinsert( base.txt, "end", nl2)
-		} # end of for i loop
-	tkinsert( base.txt, "end", nl2)
+# print( summary( dd$models[[number.of.models+1]]))
+# summaryCMD <- paste( "summary( ", full.list[ data.select], "$models$gev.fit", jj+1, ")", sep="")
+	summaryCMD <- paste( "print( summary( dd[[\"models\"]][[", number.of.models+1, "]]))", sep="")
+	eval( parse( text=summaryCMD))
+	write( summaryCMD, file="extRemes.log", append=TRUE)
 
-      nllh.str <- paste( "\n Negative log likelihood:",
-			round(dd$models[[number.of.models+1]]$nllh,4),"\n")
-      tkinsert( base.txt, "end", nllh.str)
-      tkinsert( base.txt,"end", nl1)
-	final.msg <- paste(" ", "Saved as: ", names.of.models[number.of.models+1], " ", sep="\n")
-	tkinsert( base.txt, "end", final.msg)
-      tkyview.moveto( base.txt, 1.0)
+	# tkinsert( base.txt, "end", paste( "			",
+	# 				colnames( c1)[1], "		",
+	# 				colnames( c1)[2]))
+	# tkinsert( base.txt, "end", nl2)
+#	for( i in 1:dim( c1)[1]) {
+#		tkinsert( base.txt, "end",
+#			paste( rownames( c1)[i], "	", c1[i,1],
+#					"	", c1[i,2], sep="  "))
+#		tkinsert( base.txt, "end", nl2)
+#		} # end of for i loop
+#	tkinsert( base.txt, "end", nl2)
+
+#      nllh.str <- paste( "\n Negative log likelihood:",
+#			round(dd$models[[number.of.models+1]]$nllh,4),"\n")
+
+#      tkinsert( base.txt, "end", nllh.str)
+#      tkinsert( base.txt,"end", nl1)
+	final.msg <- paste("Model name: ", names.of.models[number.of.models+1], sep="")
+	cat( final.msg)
+#	tkinsert( base.txt, "end", final.msg)
+#      tkyview.moveto( base.txt, 1.0)
 
       # plot diagnostics if requested
 
       if (tclvalue(plot.diags)==1) {
-	plot( dd$models[[number.of.models+1]])
+	write( fit.obj.cmd, file="extRemes.log", append=TRUE)
+	plotCMD <- "plot( fit.obj)"
+	eval( parse( text=plotCMD))
+	write( plotCMD, file="extRemes.log", append=TRUE)
+	# plot( dd$models[[number.of.models+1]])
       }
 
     }
  
     tkdestroy(base)
-    tkconfigure(base.txt,state="disabled")
+    # tkconfigure(base.txt,state="disabled")
 } # end of submit fcn
 
 gevfithelp <- function() {
+	cat( "\n", "Invokes the \'ismev\' function \'gev.fit\'.\n")
+	cat( "Use \'help( gev.fit)\' for more help.\n")
 	help( gev.fit)
 	} # end of gevfithelp fcn
 
@@ -368,7 +481,7 @@ gam.frm <- tkframe(base,borderwidth=2,relief="groove")
 method.frm <- tkframe( base, borderwidth=2, relief="groove")
 
 # Choose which data object to use (set the listbox to contain all objects of
-# class "ev.data").
+# class "extRemesDataObject").
 
 data.listbox <- tklistbox(data.frm,
 			yscrollcommand=function(...) tkset(data.scroll,...),
@@ -381,13 +494,13 @@ data.scroll <- tkscrollbar( data.frm, orient="vert",
 			command=function(...)tkyview(data.listbox,...))
 # initialize variables for data list.
 # 'temp' is list of everything in global environment.
-# 'full.list' will be list of all objects in '.GlobalEnv' of class "ev.data".
+# 'full.list' will be list of all objects in '.GlobalEnv' of class "extRemesDataObject".
 temp <- ls(all=TRUE, name=".GlobalEnv")
 full.list <- character(0)
 is.nothing <- TRUE
 for( i in 1:length( temp)) {
 	if( is.null( class( get( temp[i])))) next
-	if( (class(get( temp[i]))[1] == "ev.data")) {
+	if( (class(get( temp[i]))[1] == "extRemesDataObject")) {
 		tkinsert( data.listbox, "end", paste( temp[i]))
 		full.list <- c( full.list, temp[i])
 		is.nothing <- FALSE
@@ -414,8 +527,8 @@ resp.scroll <- tkscrollbar(top.l,orient="vert",
 			command=function(...)tkyview(resp.listbox,...))
 
 if( is.nothing) {
-for( i in 1:ncol(.ev$data)) 
-	tkinsert( resp.listbox, "end", paste(colnames(.ev$data)[i]))  
+for( i in 1:ncol(extRemesData$data)) 
+	tkinsert( resp.listbox, "end", paste(colnames(extRemesData$data)[i]))  
 # end of for i loop
 	} else tkinsert( resp.listbox, "end", "")
 
@@ -443,8 +556,8 @@ mu.covscr <- tkscrollbar(mu.l,orient="vert",
 		command=function(...)tkyview(mu.covlist,...)) 
 
 if( is.nothing) {
-for (i in 1:ncol(.ev$data))
-	tkinsert( mu.covlist, "end", paste( colnames( .ev$data)[i]))
+for (i in 1:ncol(extRemesData$data))
+	tkinsert( mu.covlist, "end", paste( colnames( extRemesData$data)[i]))
 # end of for i loop
 	} else tkinsert( mu.covlist, "end", "")
 
@@ -473,8 +586,8 @@ sig.covscr <- tkscrollbar(sig.l,orient="vert",
 		command=function(...)tkyview(sig.covlist,...))
 
 if( is.nothing) { 
-for (i in 1:ncol(.ev$data)) 
-	tkinsert(sig.covlist,"end",paste(colnames(.ev$data)[i]))
+for (i in 1:ncol(extRemesData$data)) 
+	tkinsert(sig.covlist,"end",paste(colnames(extRemesData$data)[i]))
 # end of for i loop
 	} else tkinsert( sig.covlist, "end", "")
 
@@ -503,8 +616,8 @@ gam.covscr <- tkscrollbar(gam.l,orient="vert",
 		command=function(...)tkyview(gam.covlist,...))
 
 if( is.nothing) { 
-for (i in 1:ncol(.ev$data))
-	tkinsert(gam.covlist,"end",paste(colnames(.ev$data)[i]))
+for (i in 1:ncol(extRemesData$data))
+	tkinsert(gam.covlist,"end",paste(colnames(extRemesData$data)[i]))
 # end of for i loop
 	} else tkinsert( gam.covlist, "end", "")
 
